==> vue-styleguidist-4.32.1.tgz: package/lib/client/utils/processSections.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.map";
import "core-js/modules/es.function.name";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/web.dom-collections.for-each";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import processComponents from './processComponents';
import compileExamples from './compileExamples';

/**
 * Recursively process each component in all sections.
 *
 * @param {Array} sections
 * @return {Array}
 */
export default function processSections(_ref) {
  var sections = _ref.sections,
      exampleFileNames = _ref.exampleFileNames;
  return sections.map(function (section) {
    compileExamples(section.content || []);
    var _section$components = section.components,
        components = _section$components === void 0 ? [] : _section$components,
        sectionsInside = section.sections;
    return _objectSpread(_objectSpread({}, section), {}, {
      visibleName: section.name,
      components: processComponents({
        components: components,
        exampleFileNames: exampleFileNames
      }),
      sections: processSections({
        sections: sectionsInside,
        exampleFileNames: exampleFileNames
      })
    });
  });
}

==> vue-styleguidist-4.32.4.tgz: package/lib/client/utils/processSections.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.map";
import "core-js/modules/es.function.name";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/web.dom-collections.for-each";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import getUrl from 'react-styleguidist/lib/client/utils/getUrl';
import processComponents from './processComponents';
import compileExamples from './compileExamples';

/**
 * Recursively process each component in all sections.
 *
 * @param {Array} sections
 * @return {Array}
 */
export default function processSections(_ref, _ref2) {
  var sections = _ref.sections,
      exampleFileNames = _ref.exampleFileNames;
  var useRouterLinks = _ref2.useRouterLinks,
      _ref2$useHashId = _ref2.useHashId,
      useHashId = _ref2$useHashId === void 0 ? false : _ref2$useHashId,
      _ref2$hashPath = _ref2.hashPath,
      hashPath = _ref2$hashPath === void 0 ? [] : _ref2$hashPath;
  return sections.map(function (section) {
    var options = {
      useRouterLinks: useRouterLinks,
      useHashId: section.sectionDepth === 0,
      hashPath: [].concat(_toConsumableArray(hashPath), [section.name ? section.name : '-'])
    };
    compileExamples(section.content || []);
    var _section$components = section.components,
        components = _section$components === void 0 ? [] : _section$components,
        sectionsInside = section.sections;
    var href = section.href || getUrl({
      name: section.name,
      slug: section.slug,
      anchor: !useRouterLinks,
      hashPath: useRouterLinks ? hashPath : false,
      useSlugAsIdParam: useRouterLinks ? useHashId : false
    });
    return _objectSpread(_objectSpread({}, section), {}, {
      visibleName: section.name,
      href: href,
      components: processComponents({
        components: components,
        exampleFileNames: exampleFileNames
      }, options),
      sections: processSections({
        sections: sectionsInside,
        exampleFileNames: exampleFileNames
      }, options)
    });
  });
}
